@@ -110,4 +110,26 @@
 #  define KXMLGUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
 
+#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x60900
+#  define KXMLGUI_DEPRECATED_VERSION_6_9(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KXMLGUI_DEPRECATED_VERSION_6_9(text)
+#endif
+
+#if KXMLGUI_DEPRECATED_WARNINGS_SINCE >= 0x60c00
+#  define KXMLGUI_DEPRECATED_VERSION_6_12(text) KXMLGUI_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KXMLGUI_DEPRECATED_VERSION_6_12(text)
+#endif
+#define KXMLGUI_DEPRECATED_VERSION_6(minor, text)      KXMLGUI_DEPRECATED_VERSION_6_##minor(text)
+#define KXMLGUI_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KXMLGUI_DEPRECATED_VERSION(major, minor, text)
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KXMLGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KXMLGUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
+
 #endif /* KXMLGUI_EXPORT_H */
